@@ -1,11 +1,17 @@
 package Config::MVP::Section;
-our $VERSION = '0.092210';
+our $VERSION = '0.092211';
 
 use Moose;
 # ABSTRACT: one section of an MVP configuration sequence
 
 
-has name    => (is => 'ro', isa => 'Str',       required => 1);
+has name => (
+  is  => 'ro',
+  isa => 'Str',
+  required => 1
+);
+
+
 has package => (
   is  => 'ro',
   isa => 'Str', # should be class-like string, but can't be ClassName
@@ -13,6 +19,7 @@ has package => (
   predicate => 'has_package',
 );
 
+
 has multivalue_args => (
   is   => 'ro',
   isa  => 'ArrayRef',
@@ -27,12 +34,6 @@ has multivalue_args => (
   },
 );
 
-has payload => (
-  is  => 'ro',
-  isa => 'HashRef',
-  init_arg => undef,
-  default  => sub { {} },
-);
 
 has aliases => (
   is  => 'ro',
@@ -46,6 +47,37 @@ has aliases => (
   },
 );
 
+
+has payload => (
+  is  => 'ro',
+  isa => 'HashRef',
+  init_arg => undef,
+  default  => sub { {} },
+);
+
+
+sub add_value {
+  my ($self, $name, $value) = @_;
+
+  my $alias = $self->aliases->{ $name };
+  $name = $alias if defined $alias;
+
+  my $mva = $self->multivalue_args;
+
+  if (grep { $_ eq $name } @$mva) {
+    my $array = $self->payload->{$name} ||= [];
+    push @$array, $value;
+    return;
+  }
+
+  if (exists $self->payload->{$name}) {
+    Carp::croak "multiple values given for property $name in section "
+              . $self->name;
+  }
+
+  $self->payload->{$name} = $value;
+}
+
 sub _BUILD_package_settings {
   my ($self) = @_;
 
@@ -69,28 +101,6 @@ sub BUILD {
   $self->_BUILD_package_settings;
 }
 
-sub add_value {
-  my ($self, $name, $value) = @_;
-
-  my $alias = $self->aliases->{ $name };
-  $name = $alias if defined $alias;
-
-  my $mva = $self->multivalue_args;
-
-  if (grep { $_ eq $name } @$mva) {
-    my $array = $self->payload->{$name} ||= [];
-    push @$array, $value;
-    return;
-  }
-
-  if (exists $self->payload->{$name}) {
-    Carp::croak "multiple values given for property $name in section "
-              . $self->name;
-  }
-
-  $self->payload->{$name} = $value;
-}
-
 no Moose;
 1;
 
@@ -104,19 +114,73 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 0.092210
+version 0.092211
 
 =head1 DESCRIPTION
 
-For the most part, you can just consult L<Config::MVP> or
-L<Config::MVP::Assembler>.
+For the most part, you can just consult L<Config::MVP> to understand what this
+class is and how it's used.
 
-Of particular note is the C<aliases> attribute.  It is a hashref.  If the
-aliases hashref is:
+=head1 ATTRIBUTES
 
-  { x => y }
+=head2 name
 
-...then attempts to add a value for the name C<x> will add it for C<y> instead.
+This is the section's name.  It's a string, and it must be provided.
+
+=head2 package
+
+This is the (Perl) package with which the section is associated.  It is
+optional.  When the section is instantiated, it will ensure that this package
+is loaded.
+
+=head2 multivalue_args
+
+This attribute is an arrayref of value names that should be considered
+multivalue properties in the section.  When added to the section, they will
+always be wrapped in an arrayref, and they may be added to the section more
+than once.
+
+If this attribute is not given during construction, it will default to the
+result of calling section's package's C<mvp_multivalue_args> method.  If the
+section has no associated package or if the package doesn't provide that
+method, it default to an empty arrayref.
+
+=head2 aliases
+
+This attribute is a hashref of name remappings.  For example, if it contains
+this hashref:
+
+  {
+    file => 'files',
+    path => 'files',
+  }
+
+Then attempting to set either the "file" or "path" setting for the section
+would actually set the "files" setting.
+
+If this attribute is not given during construction, it will default to the
+result of calling section's package's C<mvp_aliases> method.  If the
+section has no associated package or if the package doesn't provide that
+method, it default to an empty hashref.
+
+=head2 payload
+
+This is the storage into which properties are set.  It is a hashref of names
+and values.  You should probably not alter the contents of the payload, and
+should read its contents only.
+
+=head1 METHODS
+
+=head2 add_value
+
+  $section->add_value( $name => $value );
+
+This method sets the value for the named property to the given value.  If the
+property is a multivalue property, the new value will be pushed onto the end of
+an arrayref that will store all values for that property.
+
+Attempting to add a value for a non-multivalue property whose value was already
+added will result in an exception.
 
 =head1 AUTHOR
 
